@@ -723,8 +723,8 @@ static EditorUIPixmap pixmaps_map [] =
 	{ "/Toolbar/EditFind", "stock_search", EDITOR_ICON_TOOLBAR },
 	{ "/Toolbar/InsertImage", "stock_insert_image", EDITOR_ICON_TOOLBAR },
 	{ "/Toolbar/InsertLink", "stock_insert-url", EDITOR_ICON_TOOLBAR },
-	{ "/Toolbar/InsertRule", "stock_insert-rule", EDITOR_ICON_TOOLBAR },
-	{ "/Toolbar/InsertTable", "stock_insert-table", EDITOR_ICON_TOOLBAR },
+/* 	{ "/Toolbar/InsertRule", "stock_insert-rule", EDITOR_ICON_TOOLBAR }, */
+/* 	{ "/Toolbar/InsertTable", "stock_insert-table", EDITOR_ICON_TOOLBAR }, */
 
 	{ "/menu/Edit/EditUndoRedo/EditUndo", "stock_undo", EDITOR_ICON_MENU },
 	{ "/menu/Edit/EditUndoRedo/EditRedo", "stock_redo", EDITOR_ICON_MENU },
@@ -740,8 +740,8 @@ static EditorUIPixmap pixmaps_map [] =
 
 	{ "/menu/Insert/Component/InsertImage", "stock_insert_image", EDITOR_ICON_MENU },
 	{ "/menu/Insert/Component/InsertLink", "stock_insert-url", EDITOR_ICON_MENU },
-	{ "/menu/Insert/Component/InsertRule", "stock_insert-rule", EDITOR_ICON_MENU },
-	{ "/menu/Insert/Component/InsertTable", "stock_insert-table", EDITOR_ICON_MENU },
+/* 	{ "/menu/Insert/Component/InsertRule", "stock_insert-rule", EDITOR_ICON_MENU }, */
+/* 	{ "/menu/Insert/Component/InsertTable", "stock_insert-table", EDITOR_ICON_MENU }, */
 };
 
 void
@@ -779,14 +779,8 @@ menubar_setup (BonoboUIComponent  *uic,
 		filename = gnome_icon_theme_lookup_icon (cd->icon_theme, pixmaps_map [i].stock_name, pixmaps_map [i].size, NULL, NULL);
 
 		if (filename) {
-			GdkPixbuf *pixbuf;
-			char *xml_pixbuf;
-
-			pixbuf = gdk_pixbuf_new_from_file (filename, NULL);
-			xml_pixbuf = bonobo_ui_util_pixbuf_to_xml (pixbuf);
-			g_object_unref (pixbuf);
-
-			bonobo_ui_component_set_prop (uic, pixmaps_map [i].path, "pixname", xml_pixbuf, NULL);
+			bonobo_ui_component_set_prop (uic, pixmaps_map [i].path, "pixtype", "filename", NULL);
+			bonobo_ui_component_set_prop (uic, pixmaps_map [i].path, "pixname", filename, NULL);
 		} else
 			g_warning ("cannot find icon: '%s' in gnome icon theme", pixmaps_map [i].stock_name);
 	}
