@@ -34,17 +34,25 @@ struct _HTMLTextSlave {
 	HTMLText *owner;
 	guint posStart;
 	guint posLen;
-	guint start_word;
 	gchar *charStart;
 
-	GList *items;
-	GList *glyphs;
+	HTMLTextPangoInfo *pi;
+	GList *glyphs; /* deprecated */
+	GSList *glyph_items;
 };
 
 struct _HTMLTextSlaveClass {
 	HTMLObjectClass object_class;
 };
 
+struct _HTMLTextSlaveGlyphItem {
+	PangoGlyphItem glyph_item;
+	PangoGlyphUnit *widths;
+
+	HTMLTextSlaveGlyphItemType type;
+};
+
+
 void        html_text_slave_type_init             (void);
 void        html_text_slave_class_init            (HTMLTextSlaveClass *klass,
 						   HTMLType            type,
@@ -53,12 +61,10 @@ void        html_text_slave_init                  (HTMLTextSlave      *slave,
 						   HTMLTextSlaveClass *klass,
 						   HTMLText           *owner,
 						   guint               posStart,
-						   guint               posLen,
-						   guint               start_word);
+						   guint               posLen);
 HTMLObject *html_text_slave_new                   (HTMLText           *owner,
 						   guint               posStart,
-						   guint               posLen,
-						   guint               start_word);
+						   guint               posLen);
 gint        html_text_slave_get_line_offset       (HTMLTextSlave      *slave,
 						   gint                offset,
 						   HTMLPainter        *p);
@@ -74,7 +80,10 @@ gint        html_text_slave_get_nb_width          (HTMLTextSlave      *slave,
 						   gboolean            lineBegin);
 GList      *html_get_glyphs_non_tab               (GList              *glyphs,
 						   PangoItem          *item,
+						   gint                ii,
 						   const gchar        *text,
 						   gint                bytes,
 						   gint                len);
+GSList     *html_text_slave_get_glyph_items       (HTMLTextSlave      *slave,
+						   HTMLPainter        *painter);
 #endif /* _HTMLTEXTSLAVE_H_ */
